@@ -152,8 +152,9 @@ def main():
     :return: the action output
     """
     # environment variables - get while running the docker
-    region_env = os.environ.get('AWS_DEFAULT_REGION', 'us-east-1')
+    region_env = os.environ.get('AWS_DEFAULT_REGION', 'us-east-2')
     dry_run = os.environ.get('dry_run', 'yes')
+    account = os.environ.get('account', '')
     policy = os.environ.get('policy', '')
     upload_data_es = os.environ.get('upload_data_es', '')
     es_host = os.environ.get('es_host', '')
@@ -167,7 +168,7 @@ def main():
                       'es_port': int(es_port),
                       'es_index': es_index,
                       'es_doc_type': 'json_doc_type',
-                      'es_add_items': {},
+                      'es_add_items': {'account': account},
                       'bucket': bucket,
                       'logs_bucket_key': 'logs',
                       's3_file_name': 'resources.json',
